@@ -48,13 +48,13 @@ class CfnCluster(
         iam_role_arn: builtins.str,
         node_type: builtins.str,
         replication_factor: jsii.Number,
-        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
+        availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
         cluster_name: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         notification_topic_arn: typing.Optional[builtins.str] = None,
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
-        security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
+        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
@@ -390,13 +390,13 @@ class CfnClusterProps:
         iam_role_arn: builtins.str,
         node_type: builtins.str,
         replication_factor: jsii.Number,
-        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
+        availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
         cluster_name: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         notification_topic_arn: typing.Optional[builtins.str] = None,
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
-        security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
+        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnCluster.SSESpecificationProperty]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
@@ -776,7 +776,7 @@ class CfnSubnetGroup(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        subnet_ids: typing.List[builtins.str],
+        subnet_ids: typing.Sequence[builtins.str],
         description: typing.Optional[builtins.str] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -880,7 +880,7 @@ class CfnSubnetGroupProps:
     def __init__(
         self,
         *,
-        subnet_ids: typing.List[builtins.str],
+        subnet_ids: typing.Sequence[builtins.str],
         description: typing.Optional[builtins.str] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
